[arvados] created: 2.6.0-490-gc2df493fd

git repository hosting git at public.arvados.org
Mon Aug 14 21:06:02 UTC 2023


        at  c2df493fdda20d9fd4e1cb92fc94e2b991ad4efe (commit)


commit c2df493fdda20d9fd4e1cb92fc94e2b991ad4efe
Author: Brett Smith <brett.smith at curii.com>
Date:   Mon Aug 14 17:04:10 2023 -0400

    20853: Modernize pdoc installation process
    
    Install to a virtualenv to accommodate PEP 668.
    
    Arvados-DCO-1.1-Signed-off-by: Brett Smith <brett.smith at curii.com>

diff --git a/doc/README.textile b/doc/README.textile
index 045517107..9799ac564 100644
--- a/doc/README.textile
+++ b/doc/README.textile
@@ -20,11 +20,13 @@ arvados/doc$ bundle install
 To generate the Python SDK documentation, these additional dependencies are needed:
 
 <pre>
-arvados/doc$ sudo apt-get install python3-pip
-arvados/doc$ pip3 install arvados-python-client
-arvados/doc$ pip3 install pdoc
+arvados/doc$ sudo apt install python3-pip python3-venv
+arvados/doc$ python3 -m venv .venv
+arvados/doc$ .venv/bin/pip install pdoc
 </pre>
 
+Then the generation process will need to be able to find @arvados/doc/.venv/bin/pdoc at . Either add that full directory to your @$PATH@, or make a @pdoc@ symlink in another directory that's already in your @$PATH at .
+
 h2. Generate HTML pages
 
 <pre>

commit 0746b6d2f948e631a4a3d977679cc96c75efe9dd
Author: Brett Smith <brett.smith at curii.com>
Date:   Mon Aug 14 17:00:57 2023 -0400

    20853: Switch from pdoc3 to pdoc
    
    pdoc is better maintained, both in terms of release cadence and in terms
    of community code of conduct.
    
    Arvados-DCO-1.1-Signed-off-by: Brett Smith <brett.smith at curii.com>

diff --git a/.gitignore b/.gitignore
index c15601803..557386b99 100644
--- a/.gitignore
+++ b/.gitignore
@@ -12,6 +12,9 @@ docker/*/generated
 docker/config.yml
 doc/.site
 doc/sdk/python/arvados
+doc/sdk/python/arvados.html
+doc/sdk/python/index.html
+doc/sdk/python/search.js
 doc/sdk/R/arvados
 doc/sdk/java-v2/javadoc
 */vendor
diff --git a/doc/README.textile b/doc/README.textile
index 85757980a..045517107 100644
--- a/doc/README.textile
+++ b/doc/README.textile
@@ -22,7 +22,7 @@ To generate the Python SDK documentation, these additional dependencies are need
 <pre>
 arvados/doc$ sudo apt-get install python3-pip
 arvados/doc$ pip3 install arvados-python-client
-arvados/doc$ pip3 install pdoc3
+arvados/doc$ pip3 install pdoc
 </pre>
 
 h2. Generate HTML pages
diff --git a/doc/Rakefile b/doc/Rakefile
index 89454940c..8f92a8f6f 100644
--- a/doc/Rakefile
+++ b/doc/Rakefile
@@ -58,10 +58,10 @@ file "sdk/python/arvados/index.html" do |t|
   if $? == 0
     raise unless system("python3", "setup.py", "build",
                         chdir: "../sdk/python", out: :err)
-    raise unless system("pdoc", "--html", "-o", "sdk/python", "../sdk/python/build/lib/arvados/",
+    raise unless system("pdoc", "-o", "sdk/python", "../sdk/python/build/lib/arvados/",
                         out: :err)
   else
-    puts "Warning: pdoc3 not found, Python documentation will not be generated".colorize(:light_red)
+    puts "Warning: pdoc not found, Python documentation will not be generated".colorize(:light_red)
   end
 end
 
@@ -202,6 +202,8 @@ end
 
 task :clean do
   rm_rf "sdk/python/arvados"
+  rm_f "sdk/python/arvados.html"
+  rm_f "sdk/python/index.html"
   rm_rf "sdk/R"
   rm_rf "sdk/java-v2/javadoc"
 end

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/build/run-tests.sh b/build/run-tests.sh
index 765b31379..6a94d6ff1 100755
--- a/build/run-tests.sh
+++ b/build/run-tests.sh
@@ -653,7 +653,7 @@ install_env() {
     . "$VENV3DIR/bin/activate"
 
     # Needed for run_test_server.py which is used by certain (non-Python) tests.
     # pdoc3 needed to generate the Python SDK documentation.
     (
         set -e
         "${VENV3DIR}/bin/pip3" install wheel
@@ -664,7 +664,7 @@ install_env() {
         "${VENV3DIR}/bin/pip3" install ciso8601
         "${VENV3DIR}/bin/pip3" install pycurl
         "${VENV3DIR}/bin/pip3" install ws4py
-        "${VENV3DIR}/bin/pip3" install pdoc3
+        "${VENV3DIR}/bin/pip3" install pdoc
         cd "$WORKSPACE/sdk/python"
         python3 setup.py install
     ) || fatal "installing PyYAML and sdk/python failed"
@@ -653,7 +653,7 @@ install_env() {
 
     # Needed for run_test_server.py which is used by certain (non-Python) tests.
-    # pdoc3 needed to generate the Python SDK documentation.
+    # pdoc needed to generate the Python SDK documentation.
     (
         set -e
-- 




More information about the arvados-commits mailing list